@@ -178,14 +178,14 @@ pd_update_general_tab (EogPropertiesDialog *prop_dlg,
 
 #if HAVE_EXIF
 static void
-eog_exif_set_label (GtkWidget *w, ExifData *exif_data, gint tag_id)
+eog_exif_set_label (GtkWidget *w, EogExifData *exif_data, gint tag_id)
 {
 	gchar exif_buffer[512];
 	const gchar *buf_ptr;
 	gchar *label_text = NULL;
 
 	if (exif_data) {
-		buf_ptr = eog_exif_util_get_value (exif_data, tag_id,
+		buf_ptr = eog_exif_data_get_value (exif_data, tag_id,
 						   exif_buffer, 512);
 
 		if (tag_id == EXIF_TAG_DATE_TIME_ORIGINAL && buf_ptr)
@@ -354,10 +354,10 @@ pd_update_metadata_tab (EogPropertiesDialog *prop_dlg,
 		}
 
 		if (gtk_widget_get_visible (priv->exif_box)) {
-			gtk_widget_hide_all (priv->exif_box);
+			gtk_widget_hide (priv->exif_box);
 		}
 		if (gtk_widget_get_visible (priv->metadata_details_box)) {
-			gtk_widget_hide_all (priv->metadata_details_box);
+			gtk_widget_hide (priv->metadata_details_box);
 		}
 
 		return;
@@ -367,7 +367,7 @@ pd_update_metadata_tab (EogPropertiesDialog *prop_dlg,
 		if (priv->netbook_mode &&
 		    !gtk_widget_get_visible (priv->metadata_details_box)) {
 			gtk_widget_show_all (priv->metadata_details_box);
-			gtk_widget_hide_all (priv->exif_details_expander);
+			gtk_widget_hide (priv->exif_details_expander);
 		}
 	}
 
@@ -491,7 +491,11 @@ pd_close_button_clicked_cb (GtkButton *button,
 
 static gboolean
 eog_properties_dialog_page_switch (GtkNotebook     *notebook,
+#if GTK_CHECK_VERSION (2, 90, 6)
+				   GtkWidget       *page,
+#else
 				   GtkNotebookPage *page,
+#endif
 				   gint             page_index,
 				   EogPropertiesDialog *prop_dlg)
 {
@@ -537,7 +541,7 @@ eog_properties_dialog_set_netbook_mode (EogPropertiesDialog *dlg,
 		if (gtk_widget_get_visible (priv->exif_box))
 			gtk_widget_show_all (priv->metadata_details_box);
 
-		gtk_widget_hide_all (priv->exif_details_expander);
+		gtk_widget_hide (priv->exif_details_expander);
 	} else {
 		gtk_widget_reparent (priv->metadata_details_sw,
 				     priv->exif_details_expander);
@@ -545,7 +549,7 @@ eog_properties_dialog_set_netbook_mode (EogPropertiesDialog *dlg,
 
 		if (gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook)) == EOG_PROPERTIES_DIALOG_PAGE_DETAILS)
 			gtk_notebook_prev_page (GTK_NOTEBOOK (priv->notebook));
-		gtk_widget_hide_all (priv->metadata_details_box);
+		gtk_widget_hide (priv->metadata_details_box);
 	}
 #endif
 }
@@ -749,7 +753,7 @@ eog_properties_dialog_init (EogPropertiesDialog *prop_dlg)
 	priv->metadata_details_sw = sw;
 
 	if (priv->netbook_mode) {
-		gtk_widget_hide_all (priv->exif_details_expander);
+		gtk_widget_hide (priv->exif_details_expander);
 		gtk_box_pack_start (GTK_BOX (priv->metadata_details_box),
 				    sw, TRUE, TRUE, 6);
 	} else {
@@ -763,8 +767,8 @@ eog_properties_dialog_init (EogPropertiesDialog *prop_dlg)
 			  	dlg);
 
 #ifndef HAVE_EXEMPI
-	gtk_widget_hide_all (xmp_box);
-	gtk_widget_hide_all (xmp_box_label);
+	gtk_widget_hide (xmp_box);
+	gtk_widget_hide (xmp_box_label);
 #endif
 
 #else
